# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class TypeCouchbaseProtectionSourceEnum(object):

    """Implementation of the 'TypeCouchbaseProtectionSource' enum.
    Specifies the type of the managed Object in Couchbase Protection Source.
    Specifies the type of an Couchbase source entity. 'kCluster' indicates a
    Couchbase cluster distributed over several physical nodes. 'kBucket'
    indicates a bucket within the Couchbase environment.


    Attributes:
        KCLUSTER: TODO: type description here.
        KBUCKET: TODO: type description here.

    """

    KCLUSTER = 'kCluster'

    KBUCKET = 'kBucket'
